@@ -75,7 +75,7 @@ arma::mat ptvdf(arma::mat x, arma::mat df, const bool lower) {
 //' @keywords internal
 //' @export
 // [[Rcpp::export]]
-arma::mat check_equivalence(const arma::uvec& typey,
+arma::mat check_equivalence(const arma::ivec& typey,
                             const bool adseq,
                             const arma::mat& tbioq,
                             const int k) {
@@ -155,7 +155,7 @@ arma::mat test_2x2_dom(const int n,
                        const arma::vec& dropout,
                        const arma::vec& Eper,
                        const arma::vec& Eco,
-                       const arma::uvec& typey,
+                       const arma::ivec& typey,
                        const bool adseq,
                        const int k,
                        const int arm_seed){
@@ -286,7 +286,7 @@ arma::mat test_2x2_rom(const int n,
                        const arma::vec& dropout,
                        const arma::vec& Eper,
                        const arma::vec& Eco,
-                       const arma::uvec& typey,
+                       const arma::ivec& typey,
                        const bool adseq,
                        const int k,
                        const int arm_seed){
@@ -450,7 +450,7 @@ arma::mat test_par_dom(const int n,
                        const arma::rowvec& uequi_tol,
                        const arma::rowvec& alpha,
                        const arma::vec& dropout,
-                       const arma::uvec& typey,
+                       const arma::ivec& typey,
                        const bool adseq,
                        const int k,
                        const int arm_seedT,
@@ -585,7 +585,7 @@ arma::mat test_par_rom(const int n,
                        const arma::rowvec& uequi_tol,
                        const arma::rowvec& alpha,
                        const arma::vec& dropout,
-                       const arma::uvec& typey,
+                       const arma::ivec& typey,
                        const bool adseq,
                        const int k,
                        const int arm_seedT,
@@ -710,7 +710,7 @@ arma::mat run_simulations_par_dom(const int nsim,
                                const arma::rowvec& uequi_tol,
                                const arma::rowvec& alpha,
                                const arma::vec& dropout,
-                               const arma::uvec& typey,
+                               const arma::ivec& typey,
                                const bool adseq,
                                const int k,
                                const arma::ivec& arm_seed_T,
@@ -799,7 +799,7 @@ arma::mat run_simulations_par_rom(const int nsim,
                                    const arma::rowvec& uequi_tol,
                                    const arma::rowvec& alpha,
                                    const arma::vec& dropout,
-                                   const arma::uvec& typey,
+                                   const arma::ivec& typey,
                                    const bool adseq,
                                    const int k,
                                    const arma::ivec& arm_seed_T,
@@ -893,7 +893,7 @@ arma::mat run_simulations_2x2_dom(const int nsim,
                                const arma::vec& dropout,
                                const arma::vec& Eper,
                                const arma::vec& Eco,
-                               const arma::uvec& typey,
+                               const arma::ivec& typey,
                                const bool adseq,
                                const int k,
                                const arma::ivec& arm_seed){
@@ -976,7 +976,7 @@ arma::mat run_simulations_2x2_dom(const int nsim,
                                    const arma::vec& dropout,
                                    const arma::vec& Eper,
                                    const arma::vec& Eco,
-                                   const arma::uvec& typey,
+                                   const arma::ivec& typey,
                                    const bool adseq,
                                    const int k,
                                    const arma::ivec& arm_seed){
